@@ -9,7 +9,7 @@ class HttpRedirectTest(BaseRenderTest):
 
     def assertHttpRedirectWorks(self, code):
         r = self.request({"url": self.mockurl("http-redirect?code=%s" % code)})
-        self.assertEqual(r.status_code, 200)
+        self.assertStatusCode(r, 200)
         self.assertIn("GET request", r.text)
         self.assertIn("{'http_code': ['%s']}" % code, r.text)
 
@@ -29,11 +29,11 @@ class HttpRedirectTest(BaseRenderTest):
 class MetaRedirectTest(BaseRenderTest):
 
     def assertRedirected(self, resp):
-        self.assertEqual(resp.status_code, 200)
+        self.assertStatusCode(resp, 200)
         self.assertIn("META REDIRECT TARGET", resp.text)
 
     def assertNotRedirected(self, resp):
-        self.assertEqual(resp.status_code, 200)
+        self.assertStatusCode(resp, 200)
         self.assertIn('<meta http-equiv="REFRESH"', resp.text)
 
     def test_meta_redirect_nowait(self):
@@ -91,11 +91,11 @@ class MetaRedirectTest(BaseRenderTest):
 
 class JsRedirectTest(BaseRenderTest):
     def assertRedirected(self, resp):
-        self.assertEqual(resp.status_code, 200)
+        self.assertStatusCode(resp, 200)
         self.assertIn("JS REDIRECT TARGET", resp.text)
 
     def assertNotRedirected(self, resp):
-        self.assertEqual(resp.status_code, 200)
+        self.assertStatusCode(resp, 200)
         self.assertNotIn("JS REDIRECT TARGET", resp.text)
         self.assertIn("Redirecting", resp.text)
 
@@ -120,10 +120,12 @@ class JsRedirectTest(BaseRenderTest):
         self.assertNotRedirected(r)
 
     def test_redirect_timer_wait(self):
+        # jsredirect-timer redirects after 0.1ms
         r = self.request({'url': self.mockurl('jsredirect-timer'), 'wait': 0.05})
         self.assertNotRedirected(r)
 
     def test_redirect_timer_wait_enough(self):
+        # jsredirect-timer redirects after 0.1s
         r = self.request({'url': self.mockurl('jsredirect-timer'), 'wait': 0.2})
         self.assertRedirected(r)
 
@@ -164,6 +166,6 @@ class JsRedirectTest(BaseRenderTest):
             "url": self.mockurl("jsredirect-non-existing"),
             "wait": 0.1,
         })
-        self.assertEqual(r.status_code, 502)
+        self.assertStatusCode(r, 502)
 
     # TODO: support for jsredirect-infinite
